<?php

namespace LicenseKeys\Controllers;

use Keygen\Keygen;
use WPMVC\MVC\Controller;
/**
 * ConfigController controller.
 * Handles all configuration related business logic.
 *
 * @author Cami Mostajo <info@10quality.com>
 * @copyright 10 Quality <http://www.10quality.com/>
 * @license GPLv3
 * @package LicenseKeys
 * @version 1.2.6
 */
class ConfigController extends Controller
{
    /**
     * Setups / creates store code if unavailable.
     * Plugin Activation.
     * @since 1.0.0
     */
    public function setup()
    {
        // Add store code
        if ( get_option( 'woocommerce_store_code' ) === false ) {
            update_option( 'woocommerce_store_code', Keygen::alphanum( 15 )->generate() );
        }
    }
    /**
     * Returns plugin action links.
     * @since 1.0.0
     * @since 1.0.10 WooCommerce from tab api to advanced.
     *
     * @param array $current Current links.
     *
     * @return array
     */
    public function action_links( $current = [] )
    {
        $links = [];
        $links[] = '<a href="'. esc_url( admin_url( 'admin.php?page=wc-settings&tab=advanced&section=license_keys' ) ).'">'
            .__( 'API Settings', 'woo-license-keys' )
            .'</a>';
        foreach ($current as $link) {
            $links[] = $link;
        }
        return $links;
    }
    /**
     * Action "plugin_row_meta"
     * @since 1.1.0
     * 
     * @param array  $classes
     * @param string $file
     */
    public function row_meta( $meta, $file )
    {
        if ( $file === 'woo-license-keys/plugin.php'
            && ! apply_filters( 'woocommerce_license_keys_has_extended', false )
        )
            $meta['extension'] = '<a href="' . esc_url( 'https://www.10quality.com/product/woocommerce-license-keys/' ) . '" aria-label="' . esc_attr__( 'Premium features', 'woo-license-keys' ) . '" target="_blank">' . esc_html__( 'Premium features', 'woo-license-keys' ) . '</a>';
        return $meta;
    }
}