<?php

use LicenseKeys\Models\LicenseKey;

/**
 * Global functions
 *
 * @author Cami Mostajo <info@10quality.com>
 * @copyright 10 Quality <http://www.10quality.com/>
 * @license GPLv3
 * @package LicenseKeys
 * @version 1.2.10
 */

if ( ! function_exists( 'wc_is_license_key' ) ) {
    /**
     * Returns flag indicating if a product is type of "License Key".
     * @since 1.2.9
     * 
     * @param int|string|WC_Product|mixed $product_or_type The product (id or object) or a type string to check.
     * 
     * @return bool
     */
    function wc_is_license_key( $product_or_type = null )
    {
        if ( $product_or_type === null ) {
            global $product;
            $product_or_type = $product;
        }
        if ( is_numeric( $product_or_type ) ) {
            $product_or_type = wc_get_product( $product_or_type );
        }
        $type = $product_or_type && is_object( $product_or_type ) && method_exists( $product_or_type , 'get_type' )
            ? $product_or_type->get_type()
            : $product_or_type;
        return apply_filters(
            'wc_is_license_key',
            is_string( $type )
                ? in_array( $type , apply_filters( 'woocommerce_license_key_types', [] ) )
                : false,
            $product_or_type,
            $type
        );
    }
}

if ( ! function_exists( 'wc_lk_show_if' ) ) {
    /**
     * Returns product types with show_if prefixed as a only string, to be used on admin product data panels.
     * @since 1.2.9
     * 
     * @param array $types License key types | Product types.
     * 
     * @return string
     */
    function wc_lk_show_if( $types )
    {
        return implode( ' ', array_map(
            function( $type ) {
                return 'show_if_' . $type;
            },
            $types
        ) );
    }
}

if ( ! function_exists( 'wc_get_license_key' ) ) {
    /**
     * Returns a License Key.
     * @since 1.2.10
     * 
     * @param string $code
     * 
     * @return \LicenseKeys\Models\LicenseKey
     */
    function wc_get_license_key( $code )
    {
        return apply_filters( 'woocommerce_license_key', LicenseKey::find( $code ) );
    }
}